@@ -224,23 +224,43 @@ class Work(ModelSQL, ModelView):
                 leafs.add(work.id)
 
         while leafs:
+            parents = set()
             for work_id in leafs:
                 work = id2work[work_id]
-                works.remove(work)
                 if not work.active:
                     continue
                 if work.parent and work.parent.id in res:
                     res[work.parent.id] += res[work_id]
-            next_leafs = set((w.id for w in works))
-            for work in works:
-                if not work.parent:
-                    continue
-                if work.parent.id in next_leafs and work.parent in works:
-                    next_leafs.remove(work.parent.id)
-            leafs = next_leafs
+                    parents.add(work.parent.id)
+            leafs = parents
 
         return res
 
+    def copy(self, ids, default=None):
+        timesheet_work_obj = self.pool.get('timesheet.work')
+
+        int_id = isinstance(ids, (int, long))
+        if int_id:
+            ids = [ids]
+
+        if default is None:
+            default = {}
+
+        timesheet_default = default.copy()
+        for key in timesheet_default.keys():
+            if key in self._columns:
+                del timesheet_default[key]
+        new_ids = []
+        for project_work in self.browse(ids):
+            timesheet_work_id = timesheet_work_obj.copy(project_work.work.id,
+                default=timesheet_default)
+            pwdefault = default.copy()
+            pwdefault['work'] = timesheet_work_id
+            new_ids.append(super(Work, self).copy(project_work.id,
+                default=pwdefault))
+        if int_id:
+            return new_ids[0]
+        return new_ids
 
     def delete(self, ids):
         timesheet_work_obj = self.pool.get('timesheet.work')
